"""Data models corresponding to the tables under the ODM2Equipment schema
	Reference: http://odm2.github.io/ODM2/schemas/ODM2_Current/schemas/ODM2Equipment.html
"""

class CalibrationActions():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Equipment_CalibrationActions.html"""

class CalibrationReferenceEquipment():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Equipment_CalibrationReferenceEquipment.html"""

class CalibrationStandards():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Equipment_CalibrationStandards.html"""

class DataloggerFileColumns():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Equipment_DataloggerFileColumns.html"""

class DataLoggerFiles():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Equipment_DataLoggerFiles.html"""

class DataLoggerProgramFiles():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Equipment_DataloggerProgramFiles.html"""

class Equipment():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Equipment_Equipment.html"""

class EquipmentModels():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Equipment_EquipmentModels.html"""

class EquipmentUsed():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Equipment_EquipmentUsed.html"""

class InstrumentOutputQuantityKind():
	""""""

class MaintenanceActions():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Equipment_MaintenanceActions.html"""

class RelatedEquipment():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Equipment_RelatedEquipment.html"""