"""Data models corresponding to the tables under the ODM2Core schema
	Reference: http://odm2.github.io/ODM2/schemas/ODM2_Current/schemas/ODM2Core.html
"""

class ActionBy():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_ActionBy.html"""

class Actions():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_Actions.html"""

class Affiliations():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_Affiliations.html"""

class Datasets():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_Datasets.html"""

class DatasetsResults():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_DatasetsResults.html"""

class FeatureActions():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_FeatureActions.html"""

class Methods():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_Methods.html"""

class Organizations():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_Organizations.html"""

class People():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_People.html"""

class ProcessingLevels():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_ProcessingLevels.html"""

class RelatedActions():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_RelatedActions.html"""

class Results():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_Results.html"""

class SamplingFeatures():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_SamplingFeatures.html"""

class TaxonomicClassifiers():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_TaxonomicClassifiers.html"""

class CV_Units():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_Units.html"""

class Variables():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Core_Variables.html"""