"""Data models corresponding to the tables under the ODM2Simulation schema
	Reference: http://odm2.github.io/ODM2/schemas/ODM2_Current/schemas/ODM2Simulation.html
"""

class ModelAffiliations ():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Simulation_ModelAffiliations.html"""

class Models ():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Simulation_Models.html"""

class RelatedModels ():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Simulation_RelatedModels.html"""

class Simulations ():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Simulation_Simulations.html"""