"""Data models corresponding to the tables under the ODM2LabAnalyses schema
	Reference: http://odm2.github.io/ODM2/schemas/ODM2_Current/schemas/ODM2LabAnalyses.html
"""

class ActionDirectives():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2LabAnalyses_ActionDirectives.html"""

class Directives():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2LabAnalyses_Directives.html"""

class SpecimenBatchPositions():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2LabAnalyses_SpecimenBatchPostions.html"""