"""Data models corresponding to the tables under the ODM2CV schema
	Reference: http://odm2.github.io/ODM2/schemas/ODM2_Current/schemas/ODM2CV.html
"""

class CV_ActionType():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_ActionType.html"""

class CV_AggregationStatistic():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_AggregationStatistic.html"""

class CV_AnnotationType():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_AnnotationType.html"""

class CV_CensorCode():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_CensorCode.html"""

class CV_DataQualityType():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_DataQualityType.html"""

class CV_DatasetType():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_DatasetType.html"""

class CV_DirectiveType():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_DirectiveType.html"""

class CV_ElevationDatum():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_ElevationDatum.html"""

class CV_EquipmentType():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_EquipmentType.html"""

class CV_FeaturesOfInterestType():
	""""""

class CV_LBNLICPMSMapper():
	""""""

class CV_Medium():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_Medium.html"""

class CV_MethodType():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_MethodType.html"""

class CV_OrganizationType():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_OrganizationType.html"""

class CV_PropertyDataType():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_PropertyDataType.html"""

class CV_QualityCode():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_QualityCode.html"""

class CV_QuantityKind():
	""""""

class CV_RelationshipType():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_RelationshipType.html"""

class CV_ResultType():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_ResultType.html"""

class CV_SamplingFeatureGeoType():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_SamplingFeatureGeoType.html"""

class CV_SamplingFeatureType():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_SamplingFeatureType.html"""

class CV_SpatialOffsetType():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_SpatialOffsetType.html"""

class CV_SpecimenCollection():
	""""""

class CV_SpecimenType():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_SpecimenType.html"""

class CV_Status():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2CV_CV_Status.html"""

class CV_TaxonomicClassifierDomain():
	""""""

class CV_Units():
	""""""

class CV_VariableDomain():
	""""""
