"""Data models corresponding to the tables under the ODM2ExtensionProperties schema
	Reference: http://odm2.github.io/ODM2/schemas/ODM2_Current/schemas/ODM2ExtensionProperties.html
"""

class ActionExtensionPropertyValues():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExtensionProperties_ActionExtensionPropertyValues.html"""

class CitationExtensionPropertyValues():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExtensionProperties_CitationExtensionPropertyValues.html"""

class ExtensionProperties():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExtensionProperties_ExtensionProperties.html"""

class MethodExtensionPropertyValues():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExtensionProperties_MethodExtensionPropertyValues.html"""

class ResultExtensionPropertyValues():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExtensionProperties_ResultExtensionPropertyValues.html"""

class SamplingFeatureExtensionPropertyValues():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExtensionProperties_SamplingFeatureExtensionPropertyValues.html"""

class VariableExtensionPropertyValues():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExtensionProperties_VariableExtensionPropertyValues.html"""
