"""Data models corresponding to the tables under the ODM2DataQuality schema
	Reference: http://odm2.github.io/ODM2/schemas/ODM2_Current/schemas/ODM2DataQuality.html
"""

class DataQuality():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2DataQuality_DataQuality.html"""

class ReferenceMaterials():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2DataQuality_ReferenceMaterials.html"""

class ReferenceMaterialValues():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2DataQuality_ReferenceMaterialValues.html"""

class ResultNormalizationValues():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2DataQuality_ResultNormalizationValues.html"""

class ResultsDataQuality():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2DataQuality_ResultsDataQuality.html"""