"""
"""

class Accounts():
    """"""

#PRT - even though this is a CV table it is for account auth so we might move this to the auth module.
class CV_Permission():
	""""""

class OrganizationsPermissions():
    """"""

class OrganizationsSamplingFeatures():
    """"""

class ResultsPermissions():
    """"""

class Roles():
    """"""

class SamplingFeaturesPermissions():
    """"""  
