"""Data models corresponding to the tables under the ODM2SamplingFeatures schema
	Reference: http://odm2.github.io/ODM2/schemas/ODM2_Current/schemas/ODM2SamplingFeatures.html
"""

class FeaturesOfInterest():
	""""""

class RelatedFeatures ():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2SamplingFeatures_RelatedFeatures.html"""

class SampledFeatures():
	""""""

class SpatialOffsets ():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2SamplingFeatures_SpatialOffsets.html"""

class SpatialReferences ():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2SamplingFeatures_SpatialReferences.html"""

class SpecimenCollections ():
	""""""	

class Specimens ():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2SamplingFeatures_Specimens.html"""

class SpecimenTaxonomicClassifiers ():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2SamplingFeatures_SpecimenTaxonomicClassifiers.html"""