"""Data models corresponding to the tables under the ODM2Core schema
	Reference: http://odm2.github.io/ODM2/schemas/ODM2_Current/schemas/ODM2ExternalIdentifiers.html
"""

class CitationExternalIdentifiers():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExternalIdentifiers_CitationExternalIdentifiers.html"""

class ExternalIdentifierSystems():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExternalIdentifiers_ExternalIdentifierSystems.html"""

class MethodExternalIdentifiers():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExternalIdentifiers_MethodExternalIdentifiers.html"""

class PersonExternalIdentifiers():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExternalIdentifiers_PersonExternalIdentifiers.html"""

class ReferenceMaterialExternalIdentifiers():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExternalIdentifiers_ReferenceMaterialExternalIdentifiers.html"""

class SamplingFeatureExternalIdentifiers():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExternalIdentifiers_SamplingFeatureExternalIdentifiers.html"""

class SpatialReferenceExternalIdentifiers():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExternalIdentifiers_SpatialReferenceExternalIdentifiers.html"""

class TaxonomicClassifierExternalIdentifiers():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExternalIdentifiers_TaxonomicClassifierExternalIdentifiers.html"""

class VariableExternalIdentifiers():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2ExternalIdentifiers_VariableExternalIdentifiers.html"""