"""Data models corresponding to the tables under the ODM2Provenance schema
	Reference: http://odm2.github.io/ODM2/schemas/ODM2_Current/schemas/ODM2Provenance.html
"""

class AuthorLists():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Provenance_AuthorLists.html"""

class Citations():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Provenance_Citations.html"""

class DataSetCitations():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Provenance_DatasetCitations.html"""

class DerivationEquations():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Provenance_DerivationEquations.html"""

class MethodCitations():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Provenance_MethodCitations.html"""
	
class RelatedAnnotations():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Provenance_RelatedAnnotations.html"""

class RelatedDatasets():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Provenance_RelatedDatasets.html"""

class RelatedResults():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Provenance_RelatedResults.html"""

class ResultDerivationEquations():
	"""http://odm2.github.io/ODM2/schemas/ODM2_Current/tables/ODM2Provenance_ResultDerivationEquations.html"""